@@ -7,7 +7,7 @@ use strict;
 
 package XML::Compile::Transport::SOAPHTTP;
 use vars '$VERSION';
-$VERSION = '2.09';
+$VERSION = '2.10';
 
 use base 'XML::Compile::Transport';
 
@@ -46,7 +46,7 @@ sub init($)
     $self->userAgent
      ( $args->{user_agent}
      , keep_alive => (exists $args->{keep_alive} ? $args->{keep_alive} : 1)
-     , timeout => ($args->{timeout} || 180)
+     , timeout    => ($args->{timeout} || 180)
      );
     $self;
 }
@@ -68,13 +68,12 @@ sub userAgent(;$)
     return $self->{user_agent} = $agent
         if defined $agent;
 
-    $self->{user_agent}
-    ||= LWP::UserAgent->new
-         ( requests_redirectable => [ qw/GET HEAD POST M-POST/ ]
-         , parse_head => 0
-         , protocols_allowed => [ qw/http https/ ]
-         , @_
-         );
+    $self->{user_agent} ||= LWP::UserAgent->new
+      ( requests_redirectable => [ qw/GET HEAD POST M-POST/ ]
+      , parse_head => 0
+      , protocols_allowed => [ qw/http https/ ]
+      , @_
+      );
 }
 
 #-------------------------------------------
